.. _newpagetypes:

Creating new page types
=======================

This module is specifically designed to easily add custom page types.

Typically, a project consists of some standard modules, and perhaps one or two custom types.
Creating these is easy, as shown in the following sections:

.. toctree::
   :maxdepth: 2

   models
   rendering
   admin
   urls
   fluent_contents
